@@ -38,11 +38,7 @@ describe 'heat::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
-            { :client_package_name => 'python3-heatclient' }
-          else
-            { :client_package_name => 'python-heatclient' }
-          end
+          { :client_package_name => 'python3-heatclient' }
         when 'RedHat'
           { :client_package_name => 'python-heatclient' }
         end
