@@ -10,9 +10,6 @@ describe 'heat' do
   let :params do
     {
       :package_ensure        => 'present',
-      :debug                 => 'False',
-      :use_stderr            => 'True',
-      :log_dir               => '/var/log/heat',
       :database_connection   => 'mysql+pymysql://user@host/database',
       :database_idle_timeout => 3600,
       :flavor                => 'keystone',
@@ -25,24 +22,13 @@ describe 'heat' do
 
   shared_examples_for 'heat' do
 
-    context 'with rabbit_host parameter' do
+    context 'with a normal setup' do
       it_configures 'a heat base installation'
-      it_configures 'rabbit without HA support (with backward compatibility)'
+      it_configures 'configures default rabbitmq parameters'
     end
 
-    context 'with rabbit_hosts parameter' do
-      context 'with one server' do
-        it_configures 'a heat base installation'
-        it_configures 'rabbit without HA support (without backward compatibility)'
-      end
-
-      context 'with multiple servers' do
-        before { params.merge!(
-          :rabbit_ha_queues    => true,
-          :amqp_durable_queues => true) }
-        it_configures 'a heat base installation'
-        it_configures 'rabbit with HA support'
-      end
+    context 'with HA support' do
+      it_configures 'configures rabbit with HA and durable'
     end
 
     context 'with rabbit heartbeat configured' do
@@ -68,7 +54,6 @@ describe 'heat' do
 
   shared_examples_for 'a heat base installation' do
 
-    it { is_expected.to contain_class('heat::logging') }
     it { is_expected.to contain_class('heat::params') }
 
     it 'installs heat common package' do
@@ -131,10 +116,6 @@ describe 'heat' do
       is_expected.to contain_heat_config('trustee/password').with_secret( true )
     end
 
-    it 'configures auth_uri for clients_keystone' do
-      is_expected.to contain_heat_config('clients_keystone/auth_uri').with_value( 'http://127.0.0.1:5000/' )
-    end
-
     it 'configures endpoint_type for clients' do
       is_expected.to contain_heat_config('clients/endpoint_type').with_value( '<SERVICE DEFAULT>' )
     end
@@ -171,7 +152,7 @@ describe 'heat' do
 
   end
 
-  shared_examples_for 'rabbit without HA support (with backward compatibility)' do
+  shared_examples_for 'configures default rabbitmq parameters' do
     it 'configures rabbit' do
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
@@ -191,54 +172,16 @@ describe 'heat' do
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>') }
   end
 
-  shared_examples_for 'rabbit without HA support (without backward compatibility)' do
-    it 'configures rabbit' do
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_oslo__messaging__rabbit('heat_config').with(
-        :rabbit_use_ssl     => '<SERVICE DEFAULT>',
-        :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
-        :kombu_ssl_certfile => '<SERVICE DEFAULT>',
-        :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
-        :kombu_ssl_version  => '<SERVICE DEFAULT>',
-      )
+  shared_examples_for 'configures rabbit with HA and durable' do
+    before do
+      params.merge!( :rabbit_ha_queues    => true,
+                     :amqp_durable_queues => true )
     end
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>') }
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>') }
-  end
 
-  shared_examples_for 'rabbit with HA support' do
-    it 'configures rabbit' do
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_oslo__messaging__rabbit('heat_config').with(
-        :rabbit_use_ssl     => '<SERVICE DEFAULT>',
-        :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
-        :kombu_ssl_certfile => '<SERVICE DEFAULT>',
-        :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
-        :kombu_ssl_version  => '<SERVICE DEFAULT>',
-      )
-    end
-    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
+    it { is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true) }
     it { is_expected.to contain_heat_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true) }
   end
 
-  shared_examples_for 'single rabbit_host with ha queues' do
-    let :params do
-      req_params.merge({'rabbit_ha_queues' => true})
-    end
-
-    it 'should contain rabbit_ha_queues' do
-      is_expected.to contain_heat_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true')
-    end
-  end
-
   shared_examples_for 'rabbit with heartbeat configured' do
     it 'configures rabbit' do
       is_expected.to contain_heat_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
@@ -342,12 +285,12 @@ describe 'heat' do
   shared_examples_for 'with ec2authtoken auth uri set' do
     before do
       params.merge!(
-        :keystone_ec2_uri => 'http://1.2.3.4:5000/v2.0/ec2tokens'
+        :keystone_ec2_uri => 'http://1.2.3.4:5000/v3/ec2tokens'
       )
     end
 
     it do
-      is_expected.to contain_heat_config('ec2authtoken/auth_uri').with_value('http://1.2.3.4:5000/v2.0/ec2tokens')
+      is_expected.to contain_heat_config('ec2authtoken/auth_uri').with_value('http://1.2.3.4:5000/v3/ec2tokens')
     end
   end
 
@@ -476,11 +419,6 @@ describe 'heat' do
     end
   end
 
-  shared_examples_for "with custom heat_clients_keystone_uri" do
-      before { params.merge!( :heat_clients_keystone_uri => 'https://domain1/' ) }
-      it { is_expected.to contain_heat_config('clients_keystone/auth_uri').with_value('https://domain1/') }
-  end
-
   on_supported_os({
     :supported_os   => OSDefaults.get_supported_os
   }).each do |os,facts|
